---
title: ADGs - Alternative Diet Guests and Foodservice
description: Breaking down the alternative-diet restaurant experience to offer some perspective and advice to foodservice professionals and proprietors.
date: 2023-10-03
tags:
  - Vegan Cooking
  - Restaurants
synopsis: Breaking down the alternative-diet restaurant experience to offer some perspective and advice to foodservice professionals and proprietors.
imageURL: /img/k8-sWEpcc0Rm0U-unsplash.webp
imageAlt: An overhead view of a restaurant interior showing guests sitting at tables with white tablecloths, eating pastries.
mastodon_id: "111173763912666764"
---
I've been a vegan for close to a decade. From washing dishes, slinging cocktails, and pouring latte art, to recipe development, hiring, compliance, and multi-location operations, I've also been around the block a few times when it comes to foodservice. So when I tell you that the vast majority of foodservice establishments of any stripe are utter and complete complete nightmares for people with alternative diets, I hope you'll take me at my word.

For much of human civilization, food has represented more than mere fuel. Sharing a meal is a cornerstone of social and family life for billions of us around the globe; we gather together to discuss our day, we do business, we express love, and we wax philosophical over plates, bowls, leaves, platters, and hands holding an incredible variety of foods. In the present day, a growing class of people are becoming separated from the labor of cooking, while continuing to partake in its life-giving fruits. As a result of privilege, or a lack thereof, millions have come to rely on restaurants, bars, coffee shops, food stalls and stands to sustain themselves, and to participate in the social act of eating with others. While the resultant decline in food preparation skills is troubling, it is perhaps equally concerning that, whereas food was once created as a labor of love for those close to us, decisions made in the kitchens that feed so many leave those of us with less common needs and preferences largely excluded from many establishments, and with them, the important social role that they have come to play.

## For those with alternative diets, restaurants can be a source of stress.

For me and others like me, visiting a restaurant can be a difficult experience. From front of house staff with no idea what allergens their menu items contain, who don't understand the difference between Coeliac Disease and veganism, or who forget to include important information such as allergies or religious dietary restrictions into orders, to back of house staff who are equally uneducated on alternative dietary needs, lack the flexibility of process or inventory necessary to be accommodating, or who simply don't care and either treat accommodating guests with alternative diets as an encumbrance, or even lie outright and serve food that doesn't meet a guest's philosophical, religious, or even medical requirements, many of us have complicated feelings about going out to eat.

I once worked with a CEO who often invited the management team to dinner. We went to some of the best regarded restaurants in Chicago, but more often than not, I would wind up with a plate of french fries (dry, as the truffle aioli naturally wasn't vegan) and a glass of whiskey. Sometimes I'd be accommodated with a meal in-earnest. Once, I received an under-seasoned plate of couscous and mushy diced vegetables, and on another occasion, an over-priced bowl of black-bean soup. If there did happen to be a vegan menu item, it would rarely contain any protein, leaving me hungry after the meal. What ought to have been an enjoyable evening with colleagues became a source of anxiety; failing to attend these events may have left me on the sidelines at work, but going along left me feeling excluded and wishing that I were in my home kitchen making something worth eating.

## We're everywhere, and we probably want to eat at your restaurant.

Over the years I've heard many restaurateurs, managers, and chefs balk at the idea of creating a vegan menu item, claiming that it would be a moot exercise as they don't receive any vegan custom. The fact is, however, that in almost every instance they had absolutely no idea how many of their guests complied with any sort of alternative diet. From the smallest towns to the largest cities, ADGs are everywhere. If you have any custom at all, you likely have ADGs. Groups such as vegans, vegetarians, those who keep halal or kosher, those with allergies or Coeliac Disease, and so on each comprise large numbers of people, let alone in combination. If any reasonable number of people live or work near your establishment, there are almost certainly people who wish they could eat there, so near to where they spend so much of their time, but cannot for reasons either real or perceived.

Vegans and others with alternative diets have years of bad experiences to hone our expectations; we've each mentally composed a vast list of red flags - telltale signs that an establishment is going to be more trouble than its worth. When seeing these red flags, we are likely to anticipate either outright hostility, ranging from a bad attitude to being deliberately served foods we cannot eat, a lack of knowledge from staff resulting in difficulty ordering and a low degree of trust that our meal will be safe to eat, or to simply be told that there are no options available. In these situations, we may either simply avoid an establishment, or if dragged in by friends or colleagues, stick to what we know is safe: a black coffee, a fruit bowl, or even some fries, sans aioli, and a glass of whiskey. In all likelihood, a number of tickets for $5 coffees at your establishment might have been tickets for a starter and an entrée had an ADG seen one or two suitable menu items, or even just felt as though they had a fair chance at being accommodated.

## ADG items don't just make your menu accessible to swathes of new customers, done well, they should also excite your regulars.

Besides being reductive, the assertion that it's pointless to implement a vegan menu item because the business simply isn't there also implies that ADG items will only be saleable to ADGs. I can't count the number of times I've been told by someone that they simply cannot tolerate vegan food; each time, I'm tempted to express my condolences for my conversation partner's inability to enjoy a baguette, fresh fruit, vegetables, romesco sauce, peanut butter, french fries, Oreos, Swedish Fish candy, hummus, baba ganouj, nuts, Ritz Crackers, ketchup, good dark chocolate, bagels, pretzels, most potato chips, microwave popcorn, and dried pasta, foccaccia, olives, et cetera. While vegan food may be perceived by some as a special category of food, foreign and strange, only to be consumed by yet stranger people in acts of corporal mortification, vegan food, and indeed food suitable for most ADGs, is all around us; most of us already enjoy it every day, in one way or another.

[![A banana-nut doughnut: a doughnut on a plate covered in white icing, crushed nuts, and cinnamon.](/img/banana-nut-doughnut.webp "Some strange vegan food, originally posted on [my pixelfed account](https://pixelfed.social/p/nathanu/393147142652113079).")](/img/banana-nut-doughnut.webp)


Not only is there nothing strange about the food, there is also nothing so terribly different about the people who eat it. ADGs expect all of the joy from food that anyone else does: a balance of salt, fat, and acid, contrasting textures, mouth-watering flavors and aromas, and protein to keep us feeling full and satisfied. Any dish that meets these expectations ought to be worth ordering for *any* guest. This is a tough point for many otherwise proud chefs and proprietors to swallow; all else being equal, the fact is that most competent ADG menu items should be seeing sales in line with other items. Further, ADG menu items can make a menu accessible to multiple groups at once; a vegan item is also accessible to Catholics during Lent, in most instances those who keep halal or kosher, people with red meat, egg, or dairy allergies, vegetarians, and pescetarians.

## Making good food is just the start.

Designing and executing a competent ADG item or two is a fine start, but it's just that. Establishing trust takes time and effort; there are operational and cultural shifts that need to take place before a restaurant can be considered truly accessible to ADGs. While that work takes place over time, beginning with one or two competent menu items is a low-risk way for most independent establishments and other foodservice SMEs to expand their customer base. Bodies and beliefs are infinitely varied; likewise, people have an inexhaustible number of reasons to choose an ADG accessible food. As the role of restaurants becomes less of an occasional treat and more of a daily necessity, investing in menu development with ADG accessibility as a goal is increasingly becoming a simple matter of good business sense.
